@@ -30,6 +30,7 @@
 #' * `learner` :: [`Learner`][mlr3::Learner] \cr
 #'   [`Learner`][mlr3::Learner] to use for cross validation / prediction, or a string identifying a
 #'   [`Learner`][mlr3::Learner] in the [`mlr3::mlr_learners`] [`Dictionary`][mlr3misc::Dictionary].
+#'  This argument is always cloned; to access the [`Learner`][mlr3::Learner] inside `PipeOpLearnerCV` by-reference, use `$learner`.\cr
 #' * `id` :: `character(1)`
 #'   Identifier of the resulting object, internally defaulting to the `id` of the [`Learner`][mlr3::Learner] being wrapped.
 #' * `param_vals` :: named `list`\cr
@@ -151,7 +152,7 @@ PipeOpLearnerCV = R6Class("PipeOpLearnerCV",
     learner_model = function(val) {
       if (!missing(val)) {
         if (!identical(val, private$.learner)) {
-          stop("$learner is read-only.")
+          stop("$learner_model is read-only.")
         }
       }
       if (is.null(self$state) || is_noop(self$state)) {
