@@ -289,7 +289,7 @@ PipeOpTextVectorizer = R6Class("PipeOpTextVectorizer",
       }
       remove = c(remove, pv$extra_stopwords)
       # document-feature matrix
-      tdm = invoke(quanteda::dfm, .args = c(list(x = tkn, remove = remove), self$param_set$get_values(tags = "dfm")))
+      tdm = invoke(quanteda::dfm, .args = c(list(x = quanteda::tokens_remove(x = tkn, remove, valuetype = "fixed")), self$param_set$get_values(tags = "dfm")))
       # trim rare tokens
       if (trim) {
         invoke(quanteda::dfm_trim, .args = c(list(x = tdm), self$param_set$get_values(tags = "dfm_trim")))
