@@ -112,8 +112,10 @@ test_that("input / output lists and naming", {
     "list\\(input_1 = 1, input_2 = 2\\)")
 
 
-  expect_error(gr$train(list(debug.multi.input_2 = 2, debug.multi.input_99 = 1), single_input = FALSE),
-    "debug.multi.input_1,debug.multi.input_2")
+  if (packageVersion("checkmate") >= "2.1.0") {
+    expect_error(gr$train(list(debug.multi.input_2 = 2, debug.multi.input_99 = 1), single_input = FALSE),
+      "debug.multi.input_1")
+  }
 
   expect_error(gr$train(list(), single_input = FALSE), "have length 2")
   expect_error(gr$train(list(1, 2, 3), single_input = FALSE), "have length 2")
@@ -259,6 +261,14 @@ test_that("Empty Graph", {
   expect_equal(Graph$new()$state, list())
 
   expect_equal(Graph$new()$update_ids()$ids(), character(0))
+
+  expect_null(chain_graphs(list(), in_place = FALSE))
+
+  expect_null(chain_graphs(list(), in_place = FALSE))
+
+  expect_null(chain_graphs(list(NULL), in_place = FALSE))
+
+  expect_null(chain_graphs(list(NULL), in_place = TRUE))
 })
 
 test_that("Graph printer aux function calculates col widths well", {
