@@ -10,7 +10,7 @@ test_that("PipeOp - General functions", {
   expect_class(po_1$param_set, "ParamSet")
   expect_list(po_1$param_set$values, names = "unique")
   expect_output(print(po_1), "PipeOp:")
-  expect_equal(po_1$packages, character(0))
+  expect_equal(po_1$packages, "mlr3pipelines")
   expect_null(po_1$state)
   assert_subset(po_1$tags, mlr_reflections$pipeops$valid_tags)
 
@@ -77,3 +77,49 @@ test_that("Errors during training set $state to NULL", {
   expect_error(po$train(list(mlr_tasks$get("iris"))), regexp = "abstract")
   expect_null(po$state)  # state is completely reset to NULL
 })
+
+test_that("Informative error and warning messages", {
+
+  gr = as_graph(lrn("classif.debug"))
+
+  gr$param_set$values$classif.debug.warning_train = 1
+  gr$param_set$values$classif.debug.warning_predict = 1
+
+  # two 'expect_warning', because we want to 'expect' that there is exactly one warning.
+  # a function argument for expect_warning that tests exactly this would be a good idea, and has therefore been removed -.-
+  expect_warning(expect_warning(gr$train(tsk("iris")), "This happened PipeOp classif.debug's \\$train\\(\\)$"), NA)
+
+  expect_warning(suppressWarnings(gr$train(tsk("iris"))), NA)
+
+  expect_warning(expect_warning(gr$predict(tsk("iris")), "This happened PipeOp classif.debug's \\$predict\\(\\)$"), NA)
+
+  expect_warning(suppressWarnings(gr$predict(tsk("iris"))), NA)
+
+
+  gr$param_set$values$classif.debug.warning_train = 0
+  gr$param_set$values$classif.debug.warning_predict = 0
+  gr$param_set$values$classif.debug.error_train = 1
+  gr$param_set$values$classif.debug.error_predict = 1
+
+  expect_error(gr$train(tsk("iris")), "This happened PipeOp classif.debug's \\$train\\(\\)$")
+
+  expect_error(gr$predict(tsk("iris")), "This happened PipeOp classif.debug's \\$predict\\(\\)$")
+
+  potest = R6::R6Class("potest", inherit = PipeOp,
+    private = list(
+      .train = function(input) {
+        self$state = list()
+        suppressWarnings(warning("test"))
+        list(1)
+      },
+      .predict = function(input) {
+        suppressWarnings(warning("test"))
+        list(1)
+      }
+    )
+  )$new(id = "potest", input = data.table(name = "input", train = "*", predict = "*"), output = data.table(name = "input", train = "*", predict = "*"))
+
+  expect_warning(potest$train(list(1)), NA)
+  expect_warning(potest$predict(list(1)), NA)
+
+})
