@@ -28,14 +28,19 @@ test_that("learner conversion in graph creation", {
   gr4 = Graph$new()$add_pipeop(PipeOpLearner$new(mlr_learners$get("classif.rpart")))
 
   expect_equal(gr1, gr2)
-  expect_equal(gr1, gr3)
-  expect_equal(gr1, gr4)
+  expect_equal(touch(gr1), touch(gr3))
+  expect_equal(gr1, touch(gr4))
 
   gr1 = po("scale") %>>% lrn("classif.rpart")
   gr2 = po("scale") %>>% mlr_pipeops$get("learner", lrn("classif.rpart"))
   gr3 = po("scale") %>>% LearnerClassifRpart$new()
   gr4 = po("scale") %>>% PipeOpLearner$new(mlr_learners$get("classif.rpart"))
 
+  gr1$param_set
+  gr2$param_set
+  gr3$param_set
+  gr4$param_set
+
   expect_equal(gr1, gr2)
   expect_equal(gr1, gr3)
   expect_equal(gr1, gr4)
