@@ -2,6 +2,7 @@ context("PipeOpTextVectorizer")
 
 test_that("PipeOpTextVectorizer - basic properties", {
   skip_if_not_installed("quanteda")
+  suppressWarnings(loadNamespace("quanteda"))  # TODO: see https://github.com/quanteda/quanteda/issues/2116 , may not be an issue in the future
 
   task = mlr_tasks$get("iris")
   # create hacky text data:
@@ -44,6 +45,7 @@ test_that("PipeOpTextVectorizer - basic properties", {
 
 test_that("PipeOpTextVectorizer - tfidf works", {
   skip_if_not_installed("quanteda")
+  suppressWarnings(loadNamespace("quanteda"))  # TODO: see https://github.com/quanteda/quanteda/issues/2116 , may not be an issue in the future
 
   task = mlr_tasks$get("iris")
   # create some text data
@@ -71,7 +73,7 @@ test_that("PipeOpTextVectorizer - tfidf works", {
   expect_true(result$ncol > 6)
   expect_true(all(result$feature_types$type == "numeric"))
 
-  trueresult = as.data.table(quanteda::convert(quanteda::dfm_tfidf(quanteda::dfm(dt$txt)), "matrix"))
+  trueresult = as.data.table(quanteda::convert(quanteda::dfm_tfidf(quanteda::dfm(quanteda::tokens(dt$txt))), "matrix"))
   colnames(trueresult) = paste0("txt.", colnames(trueresult))
 
   popresult = result$data(cols = selector_grep("^txt\\.")(result))
@@ -114,6 +116,7 @@ test_that("PipeOpTextVectorizer - tfidf works", {
 
 test_that("PipeOpTextVectorizer - bigrams", {
   skip_if_not_installed("quanteda")
+  suppressWarnings(loadNamespace("quanteda"))  # TODO: see https://github.com/quanteda/quanteda/issues/2116 , may not be an issue in the future
 
   task = mlr_tasks$get("iris")
   # create hacky text data:
@@ -150,6 +153,7 @@ test_that("PipeOpTextVectorizer - bigrams", {
 
 test_that("PipeOpTextVectorizer - integer sequence", {
   skip_if_not_installed("quanteda")
+  suppressWarnings(loadNamespace("quanteda"))  # TODO: see https://github.com/quanteda/quanteda/issues/2116 , may not be an issue in the future
 
   task = mlr_tasks$get("iris")
   # create hacky text data:
@@ -220,6 +224,7 @@ test_that("PipeOpTextVectorizer - integer sequence", {
 
 test_that("PipeOpTextVectorizer - factor sequence", {
   skip_if_not_installed("quanteda")
+  suppressWarnings(loadNamespace("quanteda"))  # TODO: see https://github.com/quanteda/quanteda/issues/2116 , may not be an issue in the future
 
   task = mlr_tasks$get("iris")
   # create hacky text data:
